import { AIotRequest } from './index';

const BASE_PATH = 'ipu';
export const flow = {
  // 系统
  systemMgmt: `${BASE_PATH}/systemMgmt/system`,
  // 服务
  moduleMgmt: `${BASE_PATH}/moduleMgmt/module`,
  // 接口
  logicMgmt: `${BASE_PATH}/logicMgmt/logic`,
  testLogic: `${BASE_PATH}/logicMgmt/testLogic`,
  database: `${BASE_PATH}/databaseMgmt/database`,
  // clone
  sysclone: `${BASE_PATH}/systemMgmt/clone`,
  modclone: `${BASE_PATH}/moduleMgmt/clone`,
  modlogic: `${BASE_PATH}/logicMgmt/clone`,
  getFunctionList: `${BASE_PATH}/functionMgmt/function`,
  // 获取版本列表
  versionMgmt: `${BASE_PATH}/versionMgmt/version`,
  systemEditMgmt: `${BASE_PATH}/versionMgmt/edit`,
  systemReleaseMgmt: `${BASE_PATH}/versionMgmt/version`,
  stableVersion: `${BASE_PATH}/versionMgmt/stableVersion`,
  serviceList: '/logic/ipu/service/list',
  getServiceDetail: '/logic/ipu/service/get'
};

// 获取系统列表
export function getSystemList(data: any) {
  return AIotRequest.get({
    url: flow.systemMgmt,
    data
  });
}

// 新增系统
export function createSystem(data: any) {
  return AIotRequest.post({
    url: flow.systemMgmt,
    data
  });
}

// 修改系统
export function updateSystem(data: any, id: any) {
  return AIotRequest.patch({
    url: `${flow.systemMgmt}/${id}`,
    data
  });
}

// 删除系统
export function deleteSystemById(data: any) {
  return AIotRequest.delete({
    url: flow.systemMgmt,
    data
  });
}
// 克隆系统
export function copySystemById(data: any, id: any) {
  return AIotRequest.post({
    url: `${flow.sysclone}/${id}`,
    data
  });
}
// 根据ID获取系统详情
export function getSystemDetailById(id: any) {
  return AIotRequest.get({
    url: `${flow.systemMgmt}/${id}`
  });
}
// 获取已上线version列表
export function getOnlineVersionList(data: any) {
  return AIotRequest.get({
    url: flow.stableVersion,
    data
  });
}
// 切换版本
export function changeVersionById(data: any, id: any) {
  return AIotRequest.patch({
    url: `${flow.systemMgmt}/${id}`,
    data
  });
}

// 点击编辑切换或者生成dev版本
export function changeVersionToEdit(id: any) {
  return AIotRequest.post({
    url: `${flow.systemEditMgmt}/${id}`
  });
}

/**
 * 版本 start
 */
export function getVersionList(id: any) {
  return AIotRequest.get({
    url: `${flow.versionMgmt}?systemId=${id}`
  });
}

/**
 * 版本 end
 */
/**
 * 模块start
 */
// 获取模块列表
export function getModuleList(data: any) {
  return AIotRequest.get({
    url: flow.moduleMgmt,
    data
  });
}
// 新增模块
export function createModule(data: any) {
  return AIotRequest.post({
    url: flow.moduleMgmt,
    data
  });
}
// 修改模块
export function updateModuleById(data: any, id: any) {
  return AIotRequest.patch({
    url: `${flow.moduleMgmt}/${id}`,
    data
  });
}
// 克隆模块
export function cloneModuleById(data: any, id: any) {
  return AIotRequest.post({
    url: `${flow.modclone}/${id}`,
    data
  });
}
// 删除模块
export function deleteModuleById(id: any) {
  return AIotRequest.delete({
    url: `${flow.moduleMgmt}/${id}`
  });
}
/**
 * 模块end
 */
/** 接口start */
// 新增接口
export function createLogic(data: any) {
  return AIotRequest.post({
    url: flow.logicMgmt,
    data
  });
}

// 编辑接口
export function updateFlowDataById(data: any, id: any) {
  return AIotRequest.patch({
    url: `${flow.logicMgmt}/${id}`,
    data
  });
}

// 删除接口
export function deleteLogicById(id: any) {
  return AIotRequest.delete({
    url: `${flow.logicMgmt}/${id}`
  });
}
// 克隆接口
export function cloneLogicById(data: any, id: any) {
  return AIotRequest.post({
    url: `${flow.modlogic}/${id}`,
    data
  });
}
// 获取接详情
export function getLogicDetailById(id: any) {
  return AIotRequest.get({
    url: `${flow.logicMgmt}/${id}`
  });
}
/** 接口end */

// 获取数据源列表
export function getSqlList() {
  return AIotRequest.get({
    url: flow.database
  });
}

// 获取域名列表接口
export function getFunctionList() {
  return AIotRequest.get({
    url: flow.getFunctionList
  });
}

// 测试接口
export function logicModeUpdate(data: any, id: any) {
  return AIotRequest.patch({
    url: `${flow.logicMgmt}/${id}`,
    data
  });
}

// 接口测试
export function testLogic(data: any, id: any) {
  return AIotRequest.post({
    url: `${flow.testLogic}/${id}`,
    data
  });
}

// 获取接口列表
export function serviceList(data: any) {
  return AIotRequest.post({
    url: flow.serviceList,
    data
  });
}

// 获取接口详情
export function getServiceDetail(data: any) {
  return AIotRequest.post({
    url: flow.getServiceDetail,
    data
  });
}

export const otherApi = {
  getSqlList: '/ipu/sqlMgmt/sql',
  downloadTemplate: 'ipu/file/databusTemplate/download',
  getSystemConfig: 'ipu/config/value'
};

// 获取接口详情
export function getSqlServiceList(data: any): Promise<any> {
  return AIotRequest.get({
    url: otherApi.getSqlList,
    data
  });
}
// 模板下载
export function downloadTemplaye() {
  return otherApi.downloadTemplate;
}

// 查询全局配置
export function getSystemConfig() {
  return AIotRequest.get({
    url: otherApi.getSystemConfig
  });
}
